/*
 * EventEditor widget
 * Copyright (C) 1998 the Free Software Foundation
 *
 * Authors: Miguel de Icaza (miguel@kernel.org)
 *          Federico Mena (quartic@gimp.org)
 *
 * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>
 * for the GNOME 2 port.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <time.h>

#include <gconf/gconf.h>
#include <gconf/gconf-client.h>

#include <mimedir/mimedir-vevent.h>

#include "calendar-editor.h"
#include "eventedit.h"
#include "gnomecal-config.h"


GtkWidget *
event_editor_new_whole_day (time_t day)
{
	GtkWidget *ce;
	MIMEDirDateTime *dtstart, *dtend;
	MIMEDirVEvent *event;
	GConfClient *gconf;
	time_t day_begin, day_end;

	event = mimedir_vevent_new ();

	/* read configuration */

	gconf = gconf_client_get_default ();

	day_begin = (time_t) gconf_client_get_int (gconf, CONFIG_CAL_DAY_START, NULL);
	day_end   = (time_t) gconf_client_get_int (gconf, CONFIG_CAL_DAY_END, NULL);

	g_object_unref (G_OBJECT (gconf));

	/* Set the start time of the event to the beginning of the day */

	dtstart = mimedir_datetime_new_from_time_t (day);
	dtstart->hour   = day_begin;
	dtstart->minute = 0;
	dtstart->second = 0;

	/* Set the end time of the event to the end of the day */

	dtend = mimedir_datetime_new_from_time_t (day);
	dtend->hour   = day_end;
	dtend->minute = 0;
	dtend->second = 0;

	g_object_set (G_OBJECT (event),
		      "dtstart", &dtstart,
		      "dtend",   &dtend,
		      NULL);

	g_object_unref (G_OBJECT (dtstart));
	g_object_unref (G_OBJECT (dtend));

	/* Create the editor */

	ce = calendar_editor_new (event);

	/* FIXME: add event to event list */

	g_object_unref (G_OBJECT (event));

	return ce;
}
